==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ProgressiveLoadStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescription } from "./ProgressiveLoadStatusEventArgsDescription";
/**
 * @hidden
 */
export let ProgressiveLoadStatusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ProgressiveLoadStatusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ProgressiveLoadStatusEventArgsDescriptionMetadata.a == null) {
                ProgressiveLoadStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ProgressiveLoadStatusEventArgsDescriptionMetadata.c(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
            }
            if (a.k(ProgressiveLoadStatusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentStatus", "Number:int");
        }
        static d(a) {
            ProgressiveLoadStatusEventArgsDescriptionMetadata.b(a);
            a.ad("ProgressiveLoadStatusEventArgs", () => new ProgressiveLoadStatusEventArgsDescription());
            a.ac("ProgressiveLoadStatusEventArgs", ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
        }
    }
    ProgressiveLoadStatusEventArgsDescriptionMetadata.$t = markType(ProgressiveLoadStatusEventArgsDescriptionMetadata, 'ProgressiveLoadStatusEventArgsDescriptionMetadata');
    ProgressiveLoadStatusEventArgsDescriptionMetadata.a = null;
    return ProgressiveLoadStatusEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ProgressiveLoadStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescription } from "./ProgressiveLoadStatusEventArgsDescription";
/**
 * @hidden
 */
export let ProgressiveLoadStatusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ProgressiveLoadStatusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ProgressiveLoadStatusEventArgsDescriptionMetadata.a == null) {
                ProgressiveLoadStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ProgressiveLoadStatusEventArgsDescriptionMetadata.c(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
            }
            if (a.k(ProgressiveLoadStatusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentStatus", "Number:int");
        }
        static d(a) {
            ProgressiveLoadStatusEventArgsDescriptionMetadata.b(a);
            a.ae("ProgressiveLoadStatusEventArgs", () => new ProgressiveLoadStatusEventArgsDescription());
            a.ad("ProgressiveLoadStatusEventArgs", ProgressiveLoadStatusEventArgsDescriptionMetadata.a);
        }
    }
    ProgressiveLoadStatusEventArgsDescriptionMetadata.$t = markType(ProgressiveLoadStatusEventArgsDescriptionMetadata, 'ProgressiveLoadStatusEventArgsDescriptionMetadata');
    ProgressiveLoadStatusEventArgsDescriptionMetadata.a = null;
    return ProgressiveLoadStatusEventArgsDescriptionMetadata;
})();
